@@ -81,10 +81,6 @@ class HybridCalculationParameters(object):
 
     screen_plane_beam = None
 
-    # Star
-    #xx_star = None
-    #zz_star = None
-
     # Screen
     wenergy     = None
     wwavelength = None
@@ -141,6 +137,7 @@ class HybridCalculationParameters(object):
     dif_x = None
     dif_z = None
     dif_xpzp = None
+    dif_xz = None
 
     # Conversion Output
     dx_conv = None
@@ -171,7 +168,6 @@ def hy_run(input_parameters=HybridInputParameters()):
         input_parameters.widget.set_progress_bar(10)
 
         if input_parameters.ghy_diff_plane == 4:
-
             # FIRST: X DIRECTION
             input_parameters.ghy_diff_plane = 1
 
@@ -499,12 +495,9 @@ def hy_readfiles(input_parameters=HybridInputParameters(), calculation_parameter
         input_parameters.shadow_beam = ShadowBeam.traceFromOE(input_parameters.shadow_beam, screen_slit)
 
     str_n_oe = str(input_parameters.shadow_beam._oe_number)
-
-    if input_parameters.shadow_beam._oe_number < 10:
-        str_n_oe = "0" + str_n_oe
+    if input_parameters.shadow_beam._oe_number < 10: str_n_oe = "0" + str_n_oe
 
     # Before ray-tracing save the original history:
-
     calculation_parameters.original_beam_history = input_parameters.shadow_beam.getOEHistory()
 
     history_entry =  input_parameters.shadow_beam.getOEHistory(input_parameters.shadow_beam._oe_number)
@@ -516,21 +509,21 @@ def hy_readfiles(input_parameters=HybridInputParameters(), calculation_parameter
         if shadow_oe._oe.N_SCREEN == 10: raise Exception("Hybrid Screen has not been created: O.E. has already 10 screens")
 
         n_screen     = shadow_oe._oe.N_SCREEN + 1
-        i_screen     = shadow_oe._oe.I_SCREEN    
-        sl_dis       = shadow_oe._oe.I_ABS       
-        i_abs        = shadow_oe._oe.SL_DIS      
-        i_slit       = shadow_oe._oe.I_SLIT      
+        i_screen     = shadow_oe._oe.I_SCREEN
+        sl_dis       = shadow_oe._oe.I_ABS
+        i_abs        = shadow_oe._oe.SL_DIS
+        i_slit       = shadow_oe._oe.I_SLIT
         i_stop       = shadow_oe._oe.I_STOP      
         k_slit       = shadow_oe._oe.K_SLIT      
         thick        = shadow_oe._oe.THICK       
-        file_abs     = shadow_oe._oe.FILE_ABS    
+        file_abs     = numpy.copy(shadow_oe._oe.FILE_ABS)
         rx_slit      = shadow_oe._oe.RX_SLIT     
         rz_slit      = shadow_oe._oe.RZ_SLIT     
         cx_slit      = shadow_oe._oe.CX_SLIT     
         cz_slit      = shadow_oe._oe.CZ_SLIT     
-        file_scr_ext = shadow_oe._oe.FILE_SCR_EXT
+        file_scr_ext = numpy.copy(shadow_oe._oe.FILE_SCR_EXT)
         
-        index = n_screen-1
+        index = n_screen - 1
         
         i_screen[index] = 0 
         sl_dis[index] = 0       
@@ -542,7 +535,7 @@ def hy_readfiles(input_parameters=HybridInputParameters(), calculation_parameter
         rx_slit[index] = 0
         rz_slit[index] = 0      
         cx_slit[index] = 0      
-        cz_slit[index] = 0      
+        cz_slit[index] = 0
     else:
         n_screen = 1
         i_screen = numpy.zeros(10)  # after
@@ -1464,6 +1457,11 @@ def propagate_1D_z_direction(calculation_parameters, input_parameters):
 
         input_parameters.widget.set_progress_bar(80)
 
+
+##########################################################################
+# 2D PROPAGATION ALGORITHM
+##########################################################################
+
 def propagate_2D(calculation_parameters, input_parameters):
     shadow_oe = calculation_parameters.shadow_oe_end
 
@@ -1483,7 +1481,6 @@ def propagate_2D(calculation_parameters, input_parameters):
         elif input_parameters.ghy_calcType == 3 or input_parameters.ghy_calcType == 4:
             global_phase_shift_profile = calculation_parameters.w_mirr_2D_values
 
-
         # only tangential slopes
         if input_parameters.ghy_calcType == 3 or input_parameters.ghy_calcType == 4:
             rms_slope = hy_findrmsslopefromheight(ScaledArray(np_array=global_phase_shift_profile.z_values[int(global_phase_shift_profile.size_x()/2), :],
@@ -1572,7 +1569,6 @@ def propagate_2D(calculation_parameters, input_parameters):
             phase_shifts = numpy.zeros(wavefront.size())
 
             for index in range(0, phase_shifts.shape[0]):
-
                 global_phase_shift_profile_z = ScaledArray.initialize_from_steps(global_phase_shift_profile.z_values[index, :],
                                                                                  global_phase_shift_profile.y_coord[0],
                                                                                  global_phase_shift_profile.y_coord[1] - global_phase_shift_profile.y_coord[0])
