@@ -552,9 +552,9 @@ class AbstractHybridScreen(AutomaticElement):
                     else:
                         self.plot_emtpy(84, 0)
 
-                    self.plot_histo(calculation_parameters.ff_beam, 84, 3, plot_canvas_index=1, title="Z",
+                    self.plot_histo(calculation_parameters.ff_beam, 88, 3, plot_canvas_index=1, title="Z",
                                     xtitle=r'Z [$\mu$m]', ytitle=r'Number of Rays', xum=("Z [" + u"\u03BC" + "m]"))
-                    self.plot_histo_hybrid(88, calculation_parameters.dif_z, 2, title=u"\u2206" + "Z",
+                    self.plot_histo_hybrid(92, calculation_parameters.dif_z, 2, title=u"\u2206" + "Z",
                                            xtitle=r'$\Delta$Z [$\mu$m]', ytitle=r'Arbitrary Units', var=2)
                     self.plot_histo(calculation_parameters.nf_beam, 96, 3, plot_canvas_index=3, title="Z",
                                     xtitle=r'Z [$\mu$m]', ytitle=r'Number of Rays', xum=("Z [" + u"\u03BC" + "m]"))
@@ -753,7 +753,6 @@ class HybridScreen(AbstractHybridScreen):
 
             if self.IS_DEVELOP: raise exception
 
-
     def convert_thickness_error_files(self, thickness_error_profile_data_files):
         self.crl_error_profiles = []
 
@@ -838,7 +837,7 @@ class HybridScreen(AbstractHybridScreen):
         if self.ghy_calcType==5:
             self.check_fields_aux()
 
-            input_parameters.crl_error_profiles = self.crl_error_profiles
+            input_parameters.absorber_error_profiles = self.crl_error_profiles
 
             if self.crl_material_data==0: input_parameters.crl_material = self.crl_material
             else: input_parameters.crl_delta = self.crl_delta
@@ -850,3 +849,4 @@ class HybridScreen(AbstractHybridScreen):
         if self.crl_material_data==0: self.crl_material = congruence.checkEmptyString(self.crl_material, "Chemical Formula")
         else: congruence.checkStrictlyPositiveNumber(self.crl_delta, "Refractive Index (\u03b4)")
         congruence.checkPositiveNumber(self.crl_scaling_factor, "Thickness Error Scaling Factor")
+
